# Baby Buddy with Tailscale Integration

![Baby Buddy with Tailscale](https://github.com/babybuddy/babybuddy/blob/master/babybuddy/static_src/logo/icon-brand.png?raw=true "babybuddy")

This project sets up a Baby Buddy instance with Tailscale VPN integration using Docker Compose. It creates a secure, private network connection for your Baby Buddy instance using Tailscale.

## Prerequisites

- Docker and Docker Compose installed on your system
- A Tailscale account and auth key (get one from https://login.tailscale.com/admin/authkeys)
- Basic understanding of Docker and networking concepts

## Project Structure
```
ts-babybuddy/
├── docker-compose.yml
├── tailscale/
│   ├── tailscale-data/  # Persistent Tailscale state
│   └── config/         # Tailscale configuration files
└── babybuddy/
    └── config/         # Baby Buddy configuration files
```

## Setup Instructions

1. **Clone the Repository**
   ```bash
   git clone https://gitea.damconsulting.llc/DAM/ts-babybuddy.git
   cd ts-babybuddy
   ```
2. Create Required Directories
    ```bash
    mkdir -p tailscale/tailscale-data
    ```
3. Configure Tailscale
    - Replace `{{YOUR_TAILSCALE_AUTHKEY}}` in the docker-compose.yml with your actual Tailscale auth key
    - Optionally, update the file in `tailscale/config/serve.json` if you need specific Tailscale serve configurations

4. Configure Baby Buddy **OPTIONAL**
    - See https://docs.baby-buddy.net/configuration/intro/ for configuration options

5. Start the Services
    ```bash
    docker-compose up -d
    ```
6. Wait for Certificate to propagate [~2m] 

7. Login with default credentials `usr:admin` `pwd:admin`

## Services

### babybuddy-ts (Tailscale)

- Runs Tailscale VPN client
- Image: tailscale/tailscale:latest
- Container name: babybuddy-ts
- Hostname: babybuddy
- Requires NET_ADMIN and SYS_MODULE capabilities
- Persists state in ./tailscale/tailscale-data
- Uses configuration from ./tailscale/config

### babybuddy

- Runs Baby Buddy Django Server
- Depends on babybuddy-ts service
- Container name: babybuddy

## Usage

- After starting the services your service should be available via tailnet at `https://babybuddy.{{YOUR_TAILNET_DOMAIN}}.ts.net` ie `https://babybuddy.tail12345.ts.net/`
- To manually get the Tailscale IP/hostname of your container:
    ```bash
    docker logs babybuddy-ts
    ```
    Look for the Tailscale IP address in the logs.

## Optional Features

- Uncomment and adjust the ports mapping if you need direct access (without Tailscale):
    ```yaml
    ports:
    - 8000:8000
    ```
- Stopping the Services
    ```bash
    docker-compose down
    ```

## Troubleshooting
- Check container logs:
    ```bash
    docker logs babybuddy-ts
    docker logs babybuddy
    ```
- Ensure your Tailscale auth key is valid and not expired
- Verify the configuration files have proper permissions
- Make sure required directories exist before starting
## Notes
- The Baby Buddy service uses the Tailscale service's network stack via network_mode: service:babybuddy-ts
- Direct port mapping is disabled by default as Tailscale handles the networking
- Services restart automatically unless explicitly stopped
- For more information:
    - Tailscale documentation: https://tailscale.com/kb/
    - Baby Buddy documentation: https://docs.baby-buddy.net/
    - Baby Buddy repo: https://github.com/babybuddy/babybuddy
    - Baby Buddy linuxserve.io repo: https://github.com/linuxserver/docker-babybuddy
